@@ -1098,106 +1098,6 @@ class _OpenCVCondition(ControlCondition):
         return s
 
 
-class _PartialLeakStatusCondition(ControlCondition):
-    Htol = 0.0001524
-
-    def __init__(self, wn, node):
-        self._node = node
-        self._backtrack = 0
-
-    def requires(self):
-        return OrderedSet([self._node])
-
-    def evaluate(self):
-        """
-        If True is returned, node._leak_model_status needs to be _DemandStatus.Partial
-        """
-        p = self._node.head - self._node.elevation
-        if p >= self.Htol:
-            return True
-        return False
-
-
-class _ZeroLeakStatusCondition(ControlCondition):
-    Htol = 0.0001524
-
-    def __init__(self, wn, node):
-        self._node = node
-        self._backtrack = 0
-
-    def requires(self):
-        return OrderedSet([self._node])
-
-    def evaluate(self):
-        """
-        If True is returned, node._leak_model_status needs to be _DemandStatus.Zero
-        """
-        p = self._node.head - self._node.elevation
-        if p <= 0:
-            return True
-        return False
-
-
-class _PartialDemandStatusCondition(ControlCondition):
-    Htol = 0.0001524
-
-    def __init__(self, wn, junction):
-        self._junction = junction
-        self._backtrack = 0
-
-    def requires(self):
-        return OrderedSet([self._junction])
-
-    def evaluate(self):
-        """
-        If True is returned, junction._demand_status needs to be _DemandStatus.Partial
-        """
-        p = self._junction.head - self._junction.elevation
-        if p >= self._junction.minimum_pressure + self.Htol and p <= self._junction.nominal_pressure - self.Htol:
-            return True
-        return False
-
-
-class _ZeroDemandStatusCondition(ControlCondition):
-    Htol = 0.0001524
-
-    def __init__(self, wn, junction):
-        self._junction = junction
-        self._backtrack = 0
-
-    def requires(self):
-        return OrderedSet([self._junction])
-
-    def evaluate(self):
-        """
-        If True is returned, junction._demand_status needs to be _DemandStatus.Zero
-        """
-        p = self._junction.head - self._junction.elevation
-        if p <= self._junction.minimum_pressure:
-            return True
-        return False
-
-
-class _FullDemandStatusCondition(ControlCondition):
-    Htol = 0.0001524
-
-    def __init__(self, wn, junction):
-        self._junction = junction
-        self._backtrack = 0
-
-    def requires(self):
-        return OrderedSet([self._junction])
-
-    def evaluate(self):
-        """
-        If True is returned, junction._demand_status needs to be _DemandStatus.Full
-        """
-        p = self._junction.head - self._junction.elevation
-        if p >= self._junction.nominal_pressure:
-            return True
-        return False
-
-
 class _ClosePowerPumpCondition(ControlCondition):
     """
     Prevents reverse flow in pumps.
