@@ -14,7 +14,7 @@ import itertools
 from collections import OrderedDict
 from wntr.utils.ordered_set import OrderedSet
 from wntr.network import Junction, Pipe, Valve, Pump, Tank, Reservoir
-from wntr.sim.network_isolation import check_for_isolated_junctions
+from wntr.sim.network_isolation import check_for_isolated_junctions, get_long_size
 
 logger = logging.getLogger(__name__)
 
@@ -149,6 +149,13 @@ class WNTRSimulator(WaterNetworkSimulator):
         self._model_updater = None
         self._source_ids = None
 
+        long_size = get_long_size()
+        if long_size == 4:
+            self._int_dtype = np.int32
+        else:
+            assert long_size == 8
+            self._int_dtype = np.int64
+
         self._initialize_name_id_maps()
         self._initialize_internal_graph()
 
@@ -162,7 +169,7 @@ class WNTRSimulator(WaterNetworkSimulator):
         return str(h)+':'+str(m)+':'+str(s)
 
     def run_sim(self, solver=NewtonSolver, backup_solver=None, solver_options=None,
-                backup_solver_options=None, convergence_error=True):
+                backup_solver_options=None, convergence_error=True, HW_approx='default'):
         """
         Run an extended period simulation (hydraulics only).
 
@@ -181,12 +188,16 @@ class WNTRSimulator(WaterNetworkSimulator):
             * BT_MAXITER: the maximum number of iterations for each line search (default = 20)
             * BACKTRACKING: whether or not to use a line search (default = True)
             * BT_START_ITER: the newton iteration at which a line search should start being used (default = 2)
+            * THREADS: the number of threads to use in constraint and jacobian computations
         backup_solver_options: dict
         convergence_error: bool (optional)
             If convergence_error is True, an error will be raised if the
             simulation does not converge. If convergence_error is False,
             a warning will be issued and results.error_code will be set to 2
             if the simulation does not converge.  Default = True.
+        HW_approx: str
+            Specifies which Hazen-Williams headloss approximation to use. Options are 'default' and 'piecewise'. Please
+            see the WNTR documentation on hydraulics for details.
         """
         if solver_options is None:
             solver_options = {}
@@ -241,11 +252,7 @@ class WNTRSimulator(WaterNetworkSimulator):
 
             logger.log(1, 'initializing hydraulic model')
 
-        if solver == 'ipopt':
-            model_type = 'ipopt'
-        else:
-            model_type = 'wntr'
-        model, model_updater = wntr.sim.hydraulics.create_hydraulic_model(wn=wn, mode=self.mode, model_type=model_type)
+        model, model_updater = wntr.sim.hydraulics.create_hydraulic_model(wn=wn, mode=self.mode, HW_approx=HW_approx)
         self._model = model
         self._model_updater = model_updater
         node_res, link_res = wntr.sim.hydraulics.initialize_results_dict(wn)
@@ -454,8 +461,8 @@ class WNTRSimulator(WaterNetworkSimulator):
                 wntr.sim.hydraulics.update_tank_heads(wn)
             wntr.sim.hydraulics.update_model_for_controls(model, wn, model_updater, self._presolve_controls)
             wntr.sim.hydraulics.update_model_for_controls(model, wn, model_updater, self._rules)
-            wntr.models.param.source_head_param(model, wn)
-            wntr.models.param.expected_demand_param(model, wn)
+            wntr.sim.models.param.source_head_param(model, wn)
+            wntr.sim.models.param.expected_demand_param(model, wn)
 
             # Solve
             solver_status, mesg = _solver_helper(model, solver, solver_options)
@@ -571,6 +578,9 @@ class WNTRSimulator(WaterNetworkSimulator):
                 vals.append(1)
                 vals.append(1)
 
+        rows = np.array(rows, dtype=self._int_dtype)
+        cols = np.array(cols, dtype=self._int_dtype)
+        vals = np.array(vals, dtype=self._int_dtype)
         self._internal_graph = scipy.sparse.csr_matrix((vals, (rows, cols)))
 
         ndx_map = OrderedDict()
@@ -587,7 +597,7 @@ class WNTRSimulator(WaterNetworkSimulator):
         self._number_of_connections = [0 for i in range(self._wn.num_nodes)]
         for node_id in self._node_id_to_name.keys():
             self._number_of_connections[node_id] = self._internal_graph.indptr[node_id+1] - self._internal_graph.indptr[node_id]
-        self._number_of_connections = np.array(self._number_of_connections, dtype=np.int64)
+        self._number_of_connections = np.array(self._number_of_connections, dtype=self._int_dtype)
 
         self._node_pairs_with_multiple_links = OrderedDict()
         for from_node_id, to_node_id in n_links.keys():
@@ -615,7 +625,7 @@ class WNTRSimulator(WaterNetworkSimulator):
         for node_name, node in self._wn.reservoirs():
             node_id = self._node_name_to_id[node_name]
             self._source_ids.append(node_id)
-        self._source_ids = np.array(self._source_ids, dtype=np.int64)
+        self._source_ids = np.array(self._source_ids, dtype=self._int_dtype)
 
     def _update_internal_graph(self):
         data = self._internal_graph.data
@@ -655,7 +665,7 @@ class WNTRSimulator(WaterNetworkSimulator):
             link = self._wn.get_link(l)
             link._is_isolated = False
 
-        node_indicator = np.ones(self._wn.num_nodes, dtype=np.int64)
+        node_indicator = np.ones(self._wn.num_nodes, dtype=self._int_dtype)
         check_for_isolated_junctions(self._source_ids, node_indicator, self._internal_graph.indptr,
                                      self._internal_graph.indices, self._internal_graph.data,
                                      self._number_of_connections)
@@ -721,33 +731,28 @@ def _solver_helper(model, solver, solver_options):
     message: str
     """
     logger.debug('solving')
-    if solver == 'ipopt':
-        model.solve()
-        sol = SolverStatus.converged, ''
-    else:
-        model.set_structure()
-        if solver is NewtonSolver:
-            _solver = NewtonSolver(solver_options)
-            sol = _solver.solve(model)
-        elif solver is scipy.optimize.fsolve:
-            x, infodict, ier, mesg = solver(model.evaluate_residuals, model.get_x(), **solver_options)
-            if ier != 1:
-                sol = SolverStatus.error, mesg
-            else:
-                model.load_var_values_from_x(x)
-                sol = SolverStatus.converged, mesg
-        elif solver in {scipy.optimize.newton_krylov, scipy.optimize.anderson, scipy.optimize.broyden1,
-                                scipy.optimize.broyden2, scipy.optimize.excitingmixing, scipy.optimize.linearmixing,
-                                scipy.optimize.diagbroyden}:
-            try:
-                x = solver(model.evaluate_residuals, model.get_x(), **solver_options)
-                model.load_var_values_from_x(x)
-                sol = SolverStatus.converged, ''
-            except:
-                sol = SolverStatus.error, ''
+    model.set_structure()
+    if solver is NewtonSolver:
+        _solver = NewtonSolver(solver_options)
+        sol = _solver.solve(model)
+    elif solver is scipy.optimize.fsolve:
+        x, infodict, ier, mesg = solver(model.evaluate_residuals, model.get_x(), **solver_options)
+        if ier != 1:
+            sol = SolverStatus.error, mesg
         else:
-            raise ValueError('Solver not recognized.')
-        model.release_structure()
+            model.load_var_values_from_x(x)
+            sol = SolverStatus.converged, mesg
+    elif solver in {scipy.optimize.newton_krylov, scipy.optimize.anderson, scipy.optimize.broyden1,
+                            scipy.optimize.broyden2, scipy.optimize.excitingmixing, scipy.optimize.linearmixing,
+                            scipy.optimize.diagbroyden}:
+        try:
+            x = solver(model.evaluate_residuals, model.get_x(), **solver_options)
+            model.load_var_values_from_x(x)
+            sol = SolverStatus.converged, ''
+        except:
+            sol = SolverStatus.error, ''
+    else:
+        raise ValueError('Solver not recognized.')
     return sol
 
 
